# OrderCheckout


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**items** | [**list[OrderItem]**](OrderItem.md) |  | 
**email** | **str** |  | 
**stripe_checkout_redirect_url** | **str** |  | [readonly] 
**stripe_checkout_session_id** | **str** |  | [readonly] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


